summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/libcvs/cvsdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/catalogmanager/libcvs/cvsdialog.cpp')
-rw-r--r--kbabel/catalogmanager/libcvs/cvsdialog.cpp70
1 files changed, 35 insertions, 35 deletions
diff --git a/kbabel/catalogmanager/libcvs/cvsdialog.cpp b/kbabel/catalogmanager/libcvs/cvsdialog.cpp
index 090b3de3..1a71cf94 100644
--- a/kbabel/catalogmanager/libcvs/cvsdialog.cpp
+++ b/kbabel/catalogmanager/libcvs/cvsdialog.cpp
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -32,7 +32,7 @@
**************************************************************************** */
// Qt include files
#include <tqcheckbox.h>
#include <tqcombobox.h>
#include <tqfileinfo.h>
@@ -60,8 +60,8 @@
#include "cvsdialog.h"
-CVSDialog::CVSDialog( CVS::Command cmd, TQWidget * parent, KSharedConfig* config )
- : KDialog( parent, "CVSDIALOG", true ), m_config( config )
+CVSDialog::CVSDialog( CVS::Command cmd, TQWidget * tqparent, KSharedConfig* config )
+ : KDialog( tqparent, "CVSDIALOG", true ), m_config( config )
{
_cmd = cmd;
p=0L;
@@ -69,7 +69,7 @@ CVSDialog::CVSDialog( CVS::Command cmd, TQWidget * parent, KSharedConfig* config
TQString temp;
- TQVBoxLayout * layout = new TQVBoxLayout( this, 6, 6, "MAIN LAYOUT" );
+ TQVBoxLayout * tqlayout = new TQVBoxLayout( this, 6, 6, "MAIN LAYOUT" );
// Set the label's text depending on the CVS command.
switch ( cmd ) {
@@ -79,18 +79,18 @@ CVSDialog::CVSDialog( CVS::Command cmd, TQWidget * parent, KSharedConfig* config
case CVS::Commit:
temp = i18n( "Commit the following files:" );
break;
- case CVS::Status:
+ case CVS::tqStatus:
temp = i18n( "Get status for the following files:" );
break;
case CVS::Diff:
temp = i18n( "Get diff for the following files:" );
break;
}
- layout->addWidget( new TQLabel( temp, this ) );
+ tqlayout->addWidget( new TQLabel( temp, this ) );
// Widget for showing the list of files.
filebox = new TQListBox( this );
- layout->addWidget( filebox );
+ tqlayout->addWidget( filebox );
// Add special widgets for 'cvs commit'.
if ( cmd == CVS::Commit ) {
@@ -101,25 +101,25 @@ CVSDialog::CVSDialog( CVS::Command cmd, TQWidget * parent, KSharedConfig* config
oldMessages = new TQComboBox( this );
oldMessages->setDuplicatesEnabled( false );
label->setBuddy( oldMessages );
- layout->addWidget( label );
- layout->addWidget( oldMessages );
+ tqlayout->addWidget( label );
+ tqlayout->addWidget( oldMessages );
// Textfield for entering a log message.
label = new TQLabel( i18n( "&Log message:" ), this );
logedit = new TQTextEdit( this );
label->setBuddy( logedit );
- layout->addWidget( label );
- layout->addWidget( logedit );
+ tqlayout->addWidget( label );
+ tqlayout->addWidget( logedit );
label = new TQLabel( i18n( "E&ncoding:" ), this );
m_encodingComboBox = new KComboBox( this );
label->setBuddy( m_encodingComboBox );
- layout->addWidget( label );
- layout->addWidget( m_encodingComboBox );
+ tqlayout->addWidget( label );
+ tqlayout->addWidget( m_encodingComboBox );
TQStringList encodingList;
// The last encoding will be added at the top of the list, when the seetings will be read.
- encodingList << i18n( "Descriptive encoding name", "Recommended ( %1 )" ).arg( "UTF-8" );
- encodingList << i18n( "Descriptive encoding name", "Locale ( %1 )" ).arg( TQTextCodec::codecForLocale()->mimeName() );
+ encodingList << i18n( "Descriptive encoding name", "Recommended ( %1 )" ).tqarg( "UTF-8" );
+ encodingList << i18n( "Descriptive encoding name", "Locale ( %1 )" ).tqarg( TQTextCodec::codecForLocale()->mimeName() );
encodingList += KGlobal::charsets()->descriptiveEncodingNames();
m_encodingComboBox->insertStringList( encodingList );
@@ -143,8 +143,8 @@ CVSDialog::CVSDialog( CVS::Command cmd, TQWidget * parent, KSharedConfig* config
case CVS::Commit:
temp = i18n( "&Commit" );
break;
- case CVS::Status:
- temp = i18n( "&Get Status" );
+ case CVS::tqStatus:
+ temp = i18n( "&Get tqStatus" );
break;
case CVS::Diff:
temp = i18n( "&Get Diff" );
@@ -156,19 +156,19 @@ CVSDialog::CVSDialog( CVS::Command cmd, TQWidget * parent, KSharedConfig* config
cancelBtn = new TQPushButton( i18n( "C&ancel" ), this );
buttons->addWidget( cancelBtn );
- layout->addLayout( buttons );
+ tqlayout->addLayout( buttons );
TQFrame * line = new TQFrame( this );
line->setFrameStyle( TQFrame::HLine | TQFrame::Sunken );
- layout->addWidget( line );
+ tqlayout->addWidget( line );
- layout->addWidget( new TQLabel( i18n( "Command output:" ), this ) );
+ tqlayout->addWidget( new TQLabel( i18n( "Command output:" ), this ) );
output = new TQTextEdit( this );
output->setReadOnly( true );
- layout->addWidget( output );
+ tqlayout->addWidget( output );
- resize( TQSize( 600, 450 ).expandedTo( minimumSizeHint( ) ) );
+ resize( TQSize( 600, 450 ).expandedTo( tqminimumSizeHint( ) ) );
if ( cmd == CVS::Commit )
logedit->setFocus( );
@@ -244,14 +244,14 @@ void CVSDialog::slotExecuteCommand( )
if ( !codec )
{
- KMessageBox::error( this, i18n( "Cannot find encoding: %1" ).arg( m_encoding ) );
+ KMessageBox::error( this, i18n( "Cannot find encoding: %1" ).tqarg( m_encoding ) );
return;
}
else if ( !codec->canEncode( msg ) )
{
const int res = KMessageBox::warningContinueCancel( this,
i18n( "The commit log message cannot be encoded in the selected encoding: %1.\n"
- "Do you want to continue?" ).arg( m_encoding ) );
+ "Do you want to continue?" ).tqarg( m_encoding ) );
if ( res != KMessageBox::Continue )
return;
}
@@ -282,7 +282,7 @@ void CVSDialog::slotExecuteCommand( )
}
// Change the command line to have the real name of the temporary file
- _commandLine.replace( "@LOG@FILE@", KProcess::quote( m_tempFile->name() ) );
+ _commandLine.tqreplace( "@LOG@FILE@", KProcess::quote( m_tempFile->name() ) );
// Update the list of log messages
if ( !msg.isEmpty() ) {
@@ -330,7 +330,7 @@ void CVSDialog::slotProcessStdout( KProcess*, char * buffer, int len )
output->setCursorPosition( output->lines( ), 0 );
// If the command is 'cvs status' or 'cvs diff' collect the output of stdout.
- if ( (_cmd == CVS::Status) || (_cmd == CVS::Diff) )
+ if ( (_cmd == CVS::tqStatus) || (_cmd == CVS::Diff) )
_statusOutput += TQString::fromLocal8Bit( buffer, len );
}
@@ -339,7 +339,7 @@ void CVSDialog::slotProcessStderr( KProcess*, char * buffer, int len )
// If an error occurs while executing the command display stderr in
// another color.
TQColor oldColor( output->color( ) );
- output->setColor( Qt::red );
+ output->setColor( TQt::red );
output->append( TQString::fromLocal8Bit( buffer, len ) );
output->setColor( oldColor );
output->setCursorPosition( output->lines( ), 0 );
@@ -348,7 +348,7 @@ void CVSDialog::slotProcessStderr( KProcess*, char * buffer, int len )
void CVSDialog::slotProcessExited( KProcess * p )
{
if ( p->exitStatus( ) )
- output->append( i18n( "[ Exited with status %1 ]" ).arg( p->exitStatus( ) ) );
+ output->append( i18n( "[ Exited with status %1 ]" ).tqarg( p->exitStatus( ) ) );
else
output->append( i18n( "[ Finished ]" ) );
@@ -383,9 +383,9 @@ void CVSDialog::readSettings( )
m_logMessages.clear();
m_squeezedLogMessages.clear();
for ( int cnt = 0; cnt < 10; cnt++ )
- if ( config->hasKey( TQString( "CommitLogMessage%1" ).arg( cnt ) ) )
+ if ( config->hasKey( TQString( "CommitLogMessage%1" ).tqarg( cnt ) ) )
{
- const TQString logMessage = config->readEntry( TQString( "CommitLogMessage%1" ).arg( cnt ) );
+ const TQString logMessage = config->readEntry( TQString( "CommitLogMessage%1" ).tqarg( cnt ) );
if ( !logMessage.isEmpty() )
{
// If the message is too long, cut it to 80 characters (or the combo box becomes too wide)
@@ -398,7 +398,7 @@ void CVSDialog::readSettings( )
}
m_encoding = config->readEntry( "CVSEncoding", "UTF-8" );
- m_encodingComboBox->insertItem( i18n( "Descriptive encoding name", "Last choice ( %1 )" ).arg( m_encoding ), 0);
+ m_encodingComboBox->insertItem( i18n( "Descriptive encoding name", "Last choice ( %1 )" ).tqarg( m_encoding ), 0);
}
}
@@ -413,7 +413,7 @@ void CVSDialog::saveSettings( )
int cnt = 0;
TQStringList::const_iterator it;
for ( it = m_logMessages.constBegin( ); it != m_logMessages.constEnd( ) && cnt < 10 ; ++it, ++cnt )
- config->writeEntry( TQString( "CommitLogMessage%1" ).arg( cnt ), *it );
+ config->writeEntry( TQString( "CommitLogMessage%1" ).tqarg( cnt ), *it );
config->writeEntry( "CVSEncoding", m_encoding );
}
@@ -32,7 +32,7 @@
**************************************************************************** */
-// Qt include files
+// TQt include files
#include <tqcheckbox.h>
#include <tqcombobox.h>